%if 0%{?fedora} <= 22
%global _hardened_build 1
%endif

%{!?tcl_version: %global tcl_version %((echo '8.5'; echo 'puts $tcl_version' | tclsh 2>/dev/null) | tail -1)}
%{!?tcl_sitearch: %global tcl_sitearch %{_libdir}/tcl%{tcl_version}}

%if 0%{?rhel} && 0%{?rhel} <= 6
%{!?__python2: %global __python2 /usr/bin/python2}
%{!?python2_sitelib: %global python2_sitelib %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python2_sitearch: %global python2_sitearch %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%{!?__global_ldflags: %global __global_ldflags -Wl,-z,relro}
%endif

Name: tktable
Version: 2.10
Release: 10%{?dist}
License: TCL
Summary: Table/matrix widget extension to Tcl/Tk
Group: Development/Libraries
Source0: http://download.sourceforge.net/tktable/Tktable%{version}.tar.gz
URL: http://tktable.sourceforge.net/
BuildRequires: tk-devel >= 8.4.7, libXt-devel

##Xvfb is needed to run a virtual X server used by tests
BuildRequires: xorg-x11-server-Xvfb
%if 0%{?rhel} && 0%{?rhel} < 6
BuildRequires: Xorg
%endif

##Fix manpage warning
Patch0: %{name}-fix_manpage.patch

BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

Requires: tk >= 8.4.7
%if 0%{?rhel} && 0%{?rhel} < 6
Requires: tcl(abi) = 8.4
%else
Requires: tcl(abi) = %{tcl_version}
%endif

%description
Tktable provides a table/matrix widget for Tk programs. Features:
multi-line cells, embedded windows, variable width columns/height rows
(interactively resizable), scrollbar support, tag styles per row,
column or cell, in-cell editing, works on UNIX, Windows and MacIntosh,
Unicode support with Tk 8.1 and above.

%package -n python-tktable
Summary: TkTable wrapper for Python 2.x with Tkinter
URL: http://tkinter.unpythonic.net/wiki/TkTable
Group: Development/Libraries
BuildRequires: python2-devel
Requires: tkinter
%{?python_provide:%python_provide python2-%{name}}
%description -n python-tktable
Updated TkTable wrapper for Python 2.x with Tkinter.

%prep

%setup -q -n Tktable%{version}
# Silence rpmlint warnings
chmod -x ChangeLog README.txt release.txt generic/tkTableCmds.c
sed -i 's/\r$//' release.txt

##Set private library paths in tests
sed -e 's|$(TCL_SRC_DIR)/library|$(TCL_SRC_DIR)|g' -i Makefile.in
sed -e 's|$(TK_SRC_DIR)/library|$(TK_SRC_DIR)|g' -i Makefile.in

##Remove potentially bad flag
sed -e 's|-fomit-frame-pointer||g' -i configure tclconfig/tcl.m4

##tkTable.test adjusted according to the error message in newer versions of tk
%if 0%{?fedora}
sed -e 's/\(bad relief\) type/\1/' -i tests/tkTable.test
%endif

%patch0 -p0

%if 0%{?rhel} && 0%{?rhel} < 6
sed -e 's|tclConfig.sh|tclConfig.threads.sh|g' -i configure
%endif

%build
# fix problem with the tcl.m4 file that came with earlier versions
# of Tcl (quoting bug in the file that was not exposed until bash
# 3.1 was packaged with FC5)
sed -i -e "s,relid',relid," configure
export LDFLAGS="%{__global_ldflags} -Wl,-z,now"
export CFLAGS="%{optflags} -Wl,-z,relro -Wl,-z,now"
%configure \
 --enable-threads --enable-shared --disable-rpath --with-x \
%ifarch x86_64 aarch64 ppc64 ppc64le
 --enable-64bit \
%endif
%if 0%{?rhel} && 0%{?rhel} < 6
 --with-tcl=%{_libdir} --with-tk=%{_libdir} \
%else
 --with-tcl=%{tcl_sitearch} --with-tk=%{_libdir} \
%endif
%if 0%{?fedora}
 --with-tcl=%{tcl_sitearch} --with-tk=%{_libdir} \
%endif
 --with-tclinclude=%{_includedir} --with-tkinclude=%{_includedir} \
 --x-libraries=%{_libdir} --x-includes=%{_includedir}/X11 --libdir=%{tcl_sitearch} \
 --mandir=%{_mandir}/mann

make %{?_smp_mflags} V=1

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

##Install python wrapper
mkdir -p $RPM_BUILD_ROOT%{python2_sitearch}/tktable
mv $RPM_BUILD_ROOT%{tcl_sitearch}/Tktable2.10/tktable.py $RPM_BUILD_ROOT%{python2_sitearch}/tktable
sed -i -e '1i#!%{__python2}' $RPM_BUILD_ROOT%{python2_sitearch}/tktable/tktable.py
chmod +x $RPM_BUILD_ROOT%{python2_sitearch}/tktable/tktable.py

##Install man-page file
mkdir -p $RPM_BUILD_ROOT%{_mandir}/mann
install -m 644 -p doc/tkTable.n $RPM_BUILD_ROOT%{_mandir}/mann

##Remove duplicated documentation
rm -rf $RPM_BUILD_ROOT%{tcl_sitearch}/Tktable%{version}/html
rm -f $RPM_BUILD_ROOT%{tcl_sitearch}/Tktable%{version}/license.txt
rm -f $RPM_BUILD_ROOT%{tcl_sitearch}/Tktable%{version}/README.txt

%clean
rm -rf $RPM_BUILD_ROOT

##Making 'Make' sensitive to failed tests
%check
%if 0%{?rhel} && 0%{?rhel} < 6
Xvfb :1 &
export DISPLAY=:1
make test 2>&1 | tee test.log
killall Xvfb
%endif
%if 0%{?fedora}
%ifarch s390 s390x
Xvfb :1 &
export DISPLAY=:1
make test 2>&1 | tee test.log
%else
xvfb-run -a make test 2>&1 | tee test.log
%endif
grep -E 'Failed[[:blank:]]+0' test.log > /dev/null
%endif

%files
%{!?_licensedir:%global license %doc}
%doc ChangeLog README.txt README.blt doc/tkTable.html release.txt
%license license.txt
%{_mandir}/mann/tkTable.*
%{tcl_sitearch}/Tktable%{version}

%files -n python-tktable
%{!?_licensedir:%global license %doc}
%license license.txt
%{python2_sitearch}/tktable/

%changelog
* Sat Dec 26 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-10
- Defined relro flags for EPEL

* Fri Dec 25 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-9
- %%check fixed on s390?

* Wed Oct 28 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-8
- Failures not checked in EPEL7

* Tue Oct 27 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-7
- tkTable.test adjusted according to the error message in newer versions of tk (bz#1272652#c9)
- Making 'Make' sensitive to failed tests (bz#1272652#c9)

* Sun Oct 25 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-6
- Remove duplicated documentation
- Install python wrapper
- Remove potentially bad flag

* Sat Oct 24 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-5
- Enabled compiler flags for hardened builds
- Avoid <tclsh: command not found> warnings

* Fri Oct 23 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-4
- Set tclConfig in EPEL5
- Set tests in EPEL5

* Sat Oct 17 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-3
- Set configure variables
- Made tests

* Sat Oct 17 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-2
- Some cleanups

* Fri Oct 16 2015 Antonio Trande <sagitterATfedoraproject.org> - 2.10-1
- Update to 2.10

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.9-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.9-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.9-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.9-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Feb 09 2008 Wart <wart at kobold.org> 2.9-11
- Rebuild for gcc 4.3
- Clarify license tag

* Fri Jan 04 2008 Sergio Pascual <sergiopr at fedoraproject.org> 2.9-10
- Rebuilt for tcl 8.5
- Following PackagingDrafts/Tcl

* Wed Mar 1 2006 Jean-Luc Fontaine <jfontain@free.fr> 2.9-9
- fixed problem in configuration stage

* Tue Feb 28 2006 Jean-Luc Fontaine <jfontain@free.fr> 2.9-8
- specified X11 includes path in configuration

* Tue Feb 28 2006 Jean-Luc Fontaine <jfontain@free.fr> 2.9-7
- require libXt-devel for building

* Tue Feb 28 2006 Jean-Luc Fontaine <jfontain@free.fr> 2.9-6
- specified X11 librairies and includes paths in configuration

* Tue Feb 28 2006 Jean-Luc Fontaine <jfontain@free.fr> 2.9-5
- rebuild for Fedora Extras 5

* Fri Nov 11 2005 Jean-Luc Fontaine <jfontain@free.fr> 2.9-4
- only require tk and tk-devel for building

* Sun May 22 2005 Jeremy Katz <katzj@redhat.com> - 2.9-3
- rebuild on all arches

* Thu Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- rebuilt

* Mon Sep 20 2004 Jean-Luc Fontaine <jfontain@free.fr> 0:2.9-0.fdr.1
- Tktable version 2.9 new source release

* Mon Dec 8 2003 Jean-Luc Fontaine <jfontain@free.fr> 0:2.8-0.fdr.10
- removed %%doc tag for manual page since rpm does it automatically

* Sun Dec 7 2003 Jean-Luc Fontaine <jfontain@free.fr> 0:2.8-0.fdr.9
- changed license to BSD like
- removed redundant XFree86 libraries build requirement
- added SMP flags to make stage

* Sun Nov 16 2003 Jean-Luc Fontaine <jfontain@free.fr> 0:2.8-0.fdr.8
- in install stage, removed some useless manual installation of
  documentation files which left them in the BUILD directory

* Sun Nov 16 2003 Jean-Luc Fontaine <jfontain@free.fr> 0:2.8-0.fdr.7
- in build requirements, work around tcl-devel and tk-devel packages non
  existence in RH 8.0 and 9

* Thu Nov 6 2003 Jean-Luc Fontaine <jfontain@free.fr> 0:2.8-0.fdr.6
- escaped percent characters in change log

* Tue Nov 4 2003 Jean-Luc Fontaine <jfontain@free.fr> 0:2.8-0.fdr.5
- use "download.sourceforge.net/..." instead of
  "prdownloads.sourceforge.net/..." to make URLs directly downloadable
- removed AutoReqProv
- used "%%setup -q -n ..." to remove unnecessary cd's.
- added -p argument to install to preserve timestamps
- replaced %%__install by install
- no longer use RPM_OPT_FLAGS in CFLAGS as make argument as %%configure
  already handles it

* Sat Nov 1 2003 Jean-Luc Fontaine <jfontain@free.fr> 0:2.8-0.fdr.4
- removed RCS line
- set Epoch to 0 and removed it from Release
- used a full macroless URL to the source tarball
- removed Packager (not used in Fedora)
- used rm instead of %%__rm macro
- use wildcards in manual pages files entry
- added epoch to build requirements

* Wed Oct 22 2003 Jean-Luc Fontaine <jfontain@free.fr> 0:2.8-0.fdr.3
- checked with rpmlint and improved accordingly
- release 3 as previous non-fedora spec file release was 2
